pub struct OutputCompressedAccountWithContext {
pub compressed_account: CompressedAccount,
pub merkle_tree: Pubkey,
}Fields
compressed_account: CompressedAccountmerkle_tree: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for OutputCompressedAccountWithContext
impl BorshDeserialize for OutputCompressedAccountWithContext
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for OutputCompressedAccountWithContext
impl Clone for OutputCompressedAccountWithContext
Sourcefn clone(&self) -> OutputCompressedAccountWithContext
fn clone(&self) -> OutputCompressedAccountWithContext
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for OutputCompressedAccountWithContext
impl Default for OutputCompressedAccountWithContext
Sourcefn default() -> OutputCompressedAccountWithContext
fn default() -> OutputCompressedAccountWithContext
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for OutputCompressedAccountWithContext
impl PartialEq for OutputCompressedAccountWithContext
Sourcefn eq(&self, other: &OutputCompressedAccountWithContext) -> bool
fn eq(&self, other: &OutputCompressedAccountWithContext) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for OutputCompressedAccountWithContext