#[repr(C)]pub struct PackedReadOnlyAddress {
pub address: [u8; 32],
pub address_merkle_tree_root_index: u16,
pub address_merkle_tree_account_index: u8,
}Fields
address: [u8; 32]address_merkle_tree_root_index: u16address_merkle_tree_account_index: u8Trait Implementations
Sourceimpl BorshDeserialize for PackedReadOnlyAddress
impl BorshDeserialize for PackedReadOnlyAddress
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for PackedReadOnlyAddress
impl Clone for PackedReadOnlyAddress
Sourcefn clone(&self) -> PackedReadOnlyAddress
fn clone(&self) -> PackedReadOnlyAddress
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for PackedReadOnlyAddress
Sourceimpl Debug for PackedReadOnlyAddress
impl Debug for PackedReadOnlyAddress
Sourceimpl Default for PackedReadOnlyAddress
impl Default for PackedReadOnlyAddress
Sourcefn default() -> PackedReadOnlyAddress
fn default() -> PackedReadOnlyAddress
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for PackedReadOnlyAddress
impl PartialEq for PackedReadOnlyAddress
Sourcefn eq(&self, other: &PackedReadOnlyAddress) -> bool
fn eq(&self, other: &PackedReadOnlyAddress) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for PackedReadOnlyAddress
Sourceimpl<'a> ZeroCopyAtMut<'a> for PackedReadOnlyAddress
impl<'a> ZeroCopyAtMut<'a> for PackedReadOnlyAddress
type ZeroCopyAtMut = ZPackedReadOnlyAddressMut<'a>
fn zero_copy_at_mut( __remaining_bytes: &'a mut [u8], ) -> Result<(Self::ZeroCopyAtMut, &'a mut [u8]), ZeroCopyError>
Sourceimpl<'a> ZeroCopyNew<'a> for PackedReadOnlyAddress
impl<'a> ZeroCopyNew<'a> for PackedReadOnlyAddress
Sourcetype ZeroCopyConfig = ()
type ZeroCopyConfig = ()
Configuration type needed to initialize this type
Sourcetype Output = <PackedReadOnlyAddress as ZeroCopyAtMut<'a>>::ZeroCopyAtMut
type Output = <PackedReadOnlyAddress as ZeroCopyAtMut<'a>>::ZeroCopyAtMut
Output type - the mutable zero-copy view of this type
Sourcefn byte_len(config: &Self::ZeroCopyConfig) -> Result<usize, ZeroCopyError>
fn byte_len(config: &Self::ZeroCopyConfig) -> Result<usize, ZeroCopyError>
Calculate the byte length needed for this type with the given configuration Read more
Sourcefn new_zero_copy(
__remaining_bytes: &'a mut [u8],
config: Self::ZeroCopyConfig,
) -> Result<(Self::Output, &'a mut [u8]), ZeroCopyError>
fn new_zero_copy( __remaining_bytes: &'a mut [u8], config: Self::ZeroCopyConfig, ) -> Result<(Self::Output, &'a mut [u8]), ZeroCopyError>
Initialize this type in a mutable byte slice with the given configuration Read more
Sourceimpl ZeroCopyStructInnerMut for PackedReadOnlyAddress
impl ZeroCopyStructInnerMut for PackedReadOnlyAddress
type ZeroCopyInnerMut = ZPackedReadOnlyAddressMut<'static>